@@ -9,12 +9,13 @@ import io
 import platform
 from datetime import timedelta
 
-from svtplay_dl.utils import is_py3, is_py2, filenamify, decode_html_entities
+from svtplay_dl.utils import is_py3, is_py2, filenamify, decode_html_entities, ensure_unicode
 from svtplay_dl.utils.terminal import get_terminal_size
 from svtplay_dl.log import log
 
 progress_stream = sys.stderr
 
+
 class ETA(object):
     """
     An ETA class, used to calculate how long it takes to process
@@ -86,6 +87,7 @@ def progress(byte, total, extra=""):
         return
     progressbar(total, byte, extra)
 
+
 def progressbar(total, pos, msg=""):
     """
     Given a total and a progress position, output a progress bar
@@ -114,6 +116,7 @@ def progressbar(total, pos, msg=""):
 
     progress_stream.write(fmt % (pos, total, bar, msg))
 
+
 def filename(options, stream):
     if options.output:
         if is_py2:
@@ -123,10 +126,7 @@ def filename(options, stream):
                 options.output = options.output.decode("utf-8")
         options.output = options.output.replace('"', '').replace("'", "").rstrip('\\')
     if not options.output or os.path.isdir(options.output):
-        error, data = stream.get_urldata()
-        if error:
-            log.error("Cant find that page")
-            return False
+        data = ensure_unicode(stream.get_urldata())
         if data is None:
             return False
         match = re.search(r"(?i)<title[^>]*>\s*(.*?)\s*</title>", data, re.S)
@@ -139,13 +139,10 @@ def filename(options, stream):
                 # output is a directory
                 options.output = os.path.join(options.output, filenamify(title_tag))
 
-    if platform.system() == "Windows":
-        # ugly hack. replace \ with / or add extra \ because c:\test\kalle.flv will add c:_tab_est\kalle.flv
-        if options.output and options.output.find("\\") > 0:
-            options.output = options.output.replace("\\", "/")
     return True
 
-def output(options, extention="mp4", openfd=True):
+
+def output(options, extention="mp4", openfd=True, mode="wb"):
     if is_py3:
         file_d = io.IOBase
     else:
@@ -155,6 +152,8 @@ def output(options, extention="mp4", openfd=True):
         ext = re.search(r"(\.[a-z0-9]+)$", options.output)
         if not ext:
             options.output = "%s.%s" % (options.output, extention)
+        if options.output_auto and ext:
+            options.output = "%s.%s" % (options.output, extention)
         if extention == "srt" and ext:
             options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
         log.info("Outfile: %s", options.output)
@@ -169,7 +168,7 @@ def output(options, extention="mp4", openfd=True):
                     log.error("File already exists. Use --force to overwrite")
                     return None
         if openfd:
-            file_d = open(options.output, "wb")
+            file_d = open(options.output, mode)
     else:
         if openfd:
             if is_py3:
@@ -179,6 +178,7 @@ def output(options, extention="mp4", openfd=True):
 
     return file_d
 
+
 def findexpisode(directory, service, name):
     match = re.search(r"-(\w+)-\w+.(\w{2,3})$", name)
     if not match:
