@@ -6,26 +6,22 @@ import copy
 import xml.etree.ElementTree as ET
 
 from svtplay_dl.service import Service
-from svtplay_dl.error import UIException
+from svtplay_dl.error import ServiceError
 from svtplay_dl.log import log
-from svtplay_dl.fetcher.hls import HLS, hlsparse
+from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.rtmp import RTMP
-from svtplay_dl.utils import get_http_data, is_py2_old
+from svtplay_dl.utils import is_py2_old
 from svtplay_dl.utils.urllib import unquote_plus
 
-class ExpressenException(UIException):
-    pass
 
 class Expressen(Service):
     supported_domains = ['expressen.se']
 
     def get(self, options):
-        error, data = self.get_urldata()
-        if error:
-            log.error("Can't get the page")
-            return
+        data = self.get_urldata()
 
         if self.exclude(options):
+            yield ServiceError("Excluding video")
             return
 
         match = re.search("xmlUrl=([^ ]+)\" ", data)
@@ -34,13 +30,13 @@ class Expressen(Service):
         else:
             match = re.search(
                 r"moviesList: \[\{\"VideoId\":\"(\d+)\"",
-                self.get_urldata()[1])
+                self.get_urldata())
             if not match:
                 log.error("Can't find video id")
                 return
             vid = match.group(1)
             xmlurl = "http://www.expressen.se/Handlers/WebTvHandler.ashx?id=%s" % vid
-        error, data = get_http_data(xmlurl)
+        data = self.http.request("get", xmlurl).content
 
         xml = ET.XML(data)
         live = xml.find("live").text
@@ -60,6 +56,6 @@ class Expressen(Service):
             yield RTMP(options2, filename, int(i.attrib["bitrate"]))
 
         ipadurl = xml.find("mobileurls").find("ipadurl").text
-        streams = hlsparse(ipadurl)
+        streams = hlsparse(options, self.http.request("get", ipadurl), ipadurl)
         for n in list(streams.keys()):
-            yield HLS(copy.copy(options), streams[n], n)
+            yield streams[n]
