@@ -4,15 +4,13 @@ import os
 
 from svtplay_dl.service import Service
 from svtplay_dl.fetcher.hds import hdsparse
-from svtplay_dl.fetcher.hls import hlsparse, HLS
+from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.log import log
 
+
 class Raw(Service):
     def get(self, options):
-        error, data = self.get_urldata()
-        if error:
-            log.error("Can't get the page")
-            return
+        data = self.get_urldata()
 
         if self.exclude(options):
             return
@@ -20,7 +18,7 @@ class Raw(Service):
         extention = False
         filename = os.path.basename(self.url[:self.url.rfind("/")-1])
         if options.output and os.path.isdir(options.output):
-            options.output = "%s/%s" % (os.path.dirname(options.output), filename)
+            options.output = os.path.join(os.path.dirname(options.output), filename)
             extention = True
         elif options.output is None:
             options.output = "%s" % filename
@@ -30,14 +28,14 @@ class Raw(Service):
             if extention:
                 options.output = "%s.flv" % options.output
 
-            streams = hdsparse(copy.copy(options), self.url)
+            streams = hdsparse(options, self.http.request("get", self.url, params={"hdcore": "3.7.0"}), self.url)
             if streams:
                 for n in list(streams.keys()):
                     yield streams[n]
         if self.url.find(".m3u8") > 0:
-            streams = hlsparse(self.url)
+            streams = hlsparse(options, self.http.request("get", self.url), self.url)
             if extention:
                 options.output = "%s.ts" % options.output
 
             for n in list(streams.keys()):
-                yield HLS(copy.copy(options), streams[n], n)
+                yield streams[n]
