@@ -7,14 +7,16 @@ import xml.etree.ElementTree as ET
 import json
 import copy
 
-from svtplay_dl.utils.urllib import urlparse, parse_qs, quote_plus, Cookie
+from svtplay_dl.utils.urllib import urlparse, parse_qs, quote_plus
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.utils import get_http_data, is_py2_old, filenamify, CookieJar
+from svtplay_dl.utils import is_py2_old, filenamify
 from svtplay_dl.log import log
-from svtplay_dl.fetcher.hls import hlsparse, HLS
+from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.rtmp import RTMP
 from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.subtitle import subtitle
+from svtplay_dl.error import ServiceError
+
 
 class Tv4play(Service, OpenGraphThumbMixin):
     supported_domains = ['tv4play.se', 'tv4.se']
@@ -22,57 +24,38 @@ class Tv4play(Service, OpenGraphThumbMixin):
     def __init__(self, url):
         Service.__init__(self, url)
         self.subtitle = None
-        self.cj = CookieJar()
+        self.cookies = {}
 
     def get(self, options):
-        error, data = self.get_urldata()
-        if error:
-            log.error("Can't get the page")
-            return
+        data = self.get_urldata()
 
         vid = findvid(self.url, data)
         if vid is None:
-            log.error("Can't find video id for %s", self.url)
+            yield ServiceError("Can't find video id for %s" % self.url)
             return
 
         if options.username and options.password:
-            # Need a dummy cookie to save cookies..
-            cc = Cookie(version=0, name='dummy',
-                        value="",
-                        port=None, port_specified=False,
-                        domain='www.tv4play.se',
-                        domain_specified=True,
-                        domain_initial_dot=True, path='/',
-                        path_specified=True, secure=False,
-                        expires=None, discard=True, comment=None,
-                        comment_url=None, rest={'HttpOnly': None})
-            self.cj.set_cookie(cc)
-            options.cookies = self.cj
-            error, data = get_http_data("https://www.tv4play.se/session/new?https=", cookiejar=self.cj)
-            auth_token = re.search('name="authenticity_token" ([a-z]+="[^"]+" )?value="([^"]+)"', data)
-            if not auth_token:
-                log.error("Can't find authenticity_token needed for user / passwdord")
-                return
-            url = "https://www.tv4play.se/session"
-            postdata3 = quote_plus("user_name=%s&password=%s&authenticity_token=%s" % (options.username, options.password, auth_token.group(2)), "=&")
-            error, data = get_http_data(url, post=postdata3, cookiejar=self.cj)
-            fail = re.search("<p class='failed-login'>([^<]+)</p>", data)
-            if fail:
-                log.error(fail.group(1))
+            work = self._login(options.username, options.password)
+            if isinstance(work, Exception):
+                yield work
                 return
+
         url = "http://premium.tv4play.se/api/web/asset/%s/play" % vid
-        error, data = get_http_data(url, cookiejar=self.cj)
-        if error:
-            xml = ET.XML(data)
+        data = self.http.request("get", url, cookies=self.cookies)
+        if data.status_code == 401:
+            xml = ET.XML(data.content)
             code = xml.find("code").text
             if code == "SESSION_NOT_AUTHENTICATED":
-                log.error("Can't access premium content")
+                yield ServiceError("Can't access premium content")
             elif code == "ASSET_PLAYBACK_INVALID_GEO_LOCATION":
-                log.error("Can't downoad this video because of geoblocked.")
+                yield ServiceError("Can't downoad this video because of geoblocked.")
             else:
-                log.error("Can't find any info for that video")
+                yield ServiceError("Can't find any info for that video")
             return
-        xml = ET.XML(data)
+        if data.status_code == 404:
+            yield ServiceError("Can't find the video api")
+            return
+        xml = ET.XML(data.content)
         ss = xml.find("items")
         if is_py2_old:
             sa = list(ss.getiterator("item"))
@@ -83,20 +66,25 @@ class Tv4play(Service, OpenGraphThumbMixin):
             if xml.find("live").text != "false":
                 options.live = True
         if xml.find("drmProtected").text == "true":
-            log.error("We cant download DRM protected content from this site.")
+            yield ServiceError("We cant download DRM protected content from this site.")
             return
 
         if options.output_auto:
             directory = os.path.dirname(options.output)
             options.service = "tv4play"
-            title = "%s-%s-%s" % (options.output, vid, options.service)
+            basename = self._autoname(vid)
+            if basename is None:
+                yield ServiceError("Cant find vid id for autonaming")
+                return
+            title = "%s-%s-%s" % (basename, vid, options.service)
             title = filenamify(title)
             if len(directory):
-                options.output = "%s/%s" % (directory, title)
+                options.output = os.path.join(directory, title)
             else:
                 options.output = title
 
         if self.exclude(options):
+            yield ServiceError("Excluding video")
             return
 
         for i in sa:
@@ -108,7 +96,7 @@ class Tv4play(Service, OpenGraphThumbMixin):
                     options.other = "-W %s -y %s" % (swf, i.find("url").text)
                     yield RTMP(copy.copy(options), i.find("base").text, i.find("bitrate").text)
                 elif parse.path[len(parse.path)-3:len(parse.path)] == "f4m":
-                    streams = hdsparse(copy.copy(options), i.find("url").text)
+                    streams = hdsparse(options, self.http.request("get", i.find("url").text, params={"hdcore": "3.7.0"}), i.find("url").text)
                     if streams:
                         for n in list(streams.keys()):
                             yield streams[n]
@@ -116,9 +104,7 @@ class Tv4play(Service, OpenGraphThumbMixin):
                 yield subtitle(copy.copy(options), "smi", i.find("url").text)
 
         url = "http://premium.tv4play.se/api/web/asset/%s/play?protocol=hls" % vid
-        error, data = get_http_data(url, cookiejar=self.cj)
-        if error:
-            return
+        data = self.http.request("get", url, cookies=self.cookies).content
         xml = ET.XML(data)
         ss = xml.find("items")
         if is_py2_old:
@@ -129,25 +115,46 @@ class Tv4play(Service, OpenGraphThumbMixin):
             if i.find("mediaFormat").text == "mp4":
                 parse = urlparse(i.find("url").text)
                 if parse.path.endswith("m3u8"):
-                    streams = hlsparse(i.find("url").text)
+                    streams = hlsparse(options, self.http.request("get", i.find("url").text), i.find("url").text)
                     for n in list(streams.keys()):
-                        yield HLS(copy.copy(options), streams[n], n)
+                        yield streams[n]
 
-    def find_all_episodes(self, options):
+    def _get_show_info(self):
         parse = urlparse(self.url)
         show = parse.path[parse.path.find("/", 1)+1:]
         if not re.search("%", show):
             show = quote_plus(show)
-        error, data = get_http_data("http://webapi.tv4play.se/play/video_assets?type=episode&is_live=false&platform=web&node_nids=%s&per_page=99999" % show)
-        if error:
-            log.error("Can't get api page")
-            return
+        data = self.http.request("get", "http://webapi.tv4play.se/play/video_assets?type=episode&is_live=false&platform=web&node_nids=%s&per_page=99999" % show).text
         jsondata = json.loads(data)
+        return jsondata
+
+    def _autoname(self, vid):
+        jsondata = self._get_show_info()
+        for i in jsondata["results"]:
+            if vid == i["id"]:
+                return i["title"]
+        return None
+
+    def find_all_episodes(self, options):
+        premium = False
+        if options.username and options.password:
+            premium = self._login(options.username, options.password)
+            if isinstance(premium, Exception):
+                log.error(premium.message)
+                return None
+
+        jsondata = self._get_show_info()
+
         episodes = []
         n = 1
         for i in jsondata["results"]:
+            if premium:
+                text = "availability_group_premium"
+            else:
+                text = "availability_group_free"
+
             try:
-                days = int(i["availability"]["availability_group_free"])
+                days = int(i["availability"][text])
             except (ValueError, TypeError):
                 days = 999
             if days > 0:
@@ -161,6 +168,21 @@ class Tv4play(Service, OpenGraphThumbMixin):
 
         return episodes
 
+    def _login(self, username, password):
+        data = self.http.request("get", "https://www.tv4play.se/session/new?https=")
+        auth_token = re.search('name="authenticity_token" ([a-z]+="[^"]+" )?value="([^"]+)"', data.text)
+        if not auth_token:
+            return ServiceError("Can't find authenticity_token needed for user / password")
+        url = "https://www.tv4play.se/session"
+        postdata = {"user_name" : username, "password": password, "authenticity_token":auth_token.group(2), "https": ""}
+        data = self.http.request("post", url, data=postdata, cookies=self.cookies)
+        self.cookies = data.cookies
+        fail = re.search("<p class='failed-login'>([^<]+)</p>", data.text)
+        if fail:
+            return ServiceError(fail.group(1))
+        return True
+
+
 def findvid(url, data):
     parse = urlparse(url)
     if "tv4play.se" in url:
