@@ -2,9 +2,11 @@ import xml.etree.ElementTree as ET
 import json
 import re
 from svtplay_dl.log import log
-from svtplay_dl.utils import is_py2, is_py3, get_http_data
+from svtplay_dl.utils import is_py2, is_py3, decode_html_entities
 from svtplay_dl.utils.io import StringIO
 from svtplay_dl.output import output
+from requests import Session
+from requests import __build__ as requests_version
 
 
 class subtitle(object):
@@ -13,12 +15,10 @@ class subtitle(object):
         self.subtitle = None
         self.options = options
         self.subtype = subtype
+        self.http = Session()
 
     def download(self):
-        error, subdata = get_http_data(self.url, cookiejar=self.options.cookies)
-        if error:
-            log.error("Can't download subtitle")
-            return
+        subdata = self.http.request("get", self.url, cookies=self.options.cookies)
 
         data = None
         if self.subtype == "tt":
@@ -32,7 +32,7 @@ class subtitle(object):
         if self.subtype == "wrst":
             data = self.wrst(subdata)
 
-        file_d = output(self.options, "srt")
+        file_d = output(self.options, "srt", mode="wt")
         if hasattr(file_d, "read") is False:
             return
         file_d.write(data)
@@ -41,7 +41,7 @@ class subtitle(object):
     def tt(self, subdata):
         i = 1
         data = ""
-        tree = ET.ElementTree(ET.fromstring(subdata))
+        tree = ET.XML(subdata.text.encode("utf8"))
         xml = tree.find("{http://www.w3.org/2006/10/ttaf1}body").find("{http://www.w3.org/2006/10/ttaf1}div")
         plist = list(xml.findall("{http://www.w3.org/2006/10/ttaf1}p"))
         for node in plist:
@@ -63,12 +63,12 @@ class subtitle(object):
                 data = tt_text(node, data)
                 data += "\n"
                 i += 1
-
-        data = data.encode('utf8')
+        if is_py2:
+            data = data.encode("utf8")
         return data
 
     def json(self, subdata):
-        data = json.loads(subdata)
+        data = json.loads(subdata.text)
         number = 1
         subs = ""
         for i in data:
@@ -82,7 +82,7 @@ class subtitle(object):
         return subs
 
     def sami(self, subdata):
-        tree = ET.XML(subdata)
+        tree = ET.XML(subdata.text.encode("utf8"))
         subt = tree.find("Font")
         subs = ""
         n = 0
@@ -98,13 +98,17 @@ class subtitle(object):
                 if int(n) > 0:
                     subs += "%s\n" % i.text
 
-
-        subs = subs.encode('utf8')
+        if is_py2:
+            subs = subs.encode('utf8')
         return subs
 
     def smi(self, subdata):
-        if is_py3:
-            subdata = subdata.decode("latin1")
+        if requests_version < 0x20300:
+            subdata = subdata.content
+            if is_py3:
+                subdata = subdata.decode("latin")
+        else:
+            subdata = subdata.text
         ssubdata = StringIO(subdata)
         timea = 0
         number = 1
@@ -130,12 +134,12 @@ class subtitle(object):
                 data = text.group(1)
         recomp = re.compile(r'\r')
         text = bad_char.sub('-', recomp.sub('', subs)).replace('&quot;', '"')
-        if is_py3:
+        if is_py2 and isinstance(text, unicode):
             return text.encode("utf-8")
         return text
 
     def wrst(self, subdata):
-        ssubdata = StringIO(subdata)
+        ssubdata = StringIO(subdata.text)
         srt = ""
         subtract = False
         number_b = 1
@@ -157,7 +161,7 @@ class subtitle(object):
                 matchx = re.search(r'(\d+):(\d+)[.:]([\d\.]+) --> (\d+):(\d+)[.:]([\d\.]+)', i)
                 hour1 = int(matchx.group(1))
                 hour2 = int(matchx.group(4))
-                if number == 1:
+                if int(number) == 1:
                     if hour1 > 9:
                         subtract = True
                 if subtract:
@@ -176,11 +180,12 @@ class subtitle(object):
             else:
                 sub = re.sub('<[^>]*>', '', i)
                 srt += sub.lstrip()
-
-        if is_py3:
+        srt = decode_html_entities(srt)
+        if is_py2:
             return srt.encode("utf-8")
         return srt
 
+
 def timestr(msec):
     """
     Convert a millisecond value to a string of the following
@@ -202,10 +207,12 @@ def timestr(msec):
     output = "%02d:%02d:%05.2f" % (hours, minutes, sec)
     return output.replace(".", ",")
 
+
 def timecolon(data):
     match = re.search(r"(\d+:\d+:\d+):(\d+)", data)
     return "%s,%s" % (match.group(1), match.group(2))
 
+
 def norm(name):
     if name[0] == "{":
         _, tag = name[1:].split("}")
@@ -213,6 +220,7 @@ def norm(name):
     else:
         return name
 
+
 def tt_text(node, data):
     if node.text:
         data += "%s\n" % node.text.strip(' \t\n\r')
